@@ -112,7 +112,7 @@ class RTJPConnection(object):
                     except core.RTJPParseException, e:
                         self.send_error(e.id, str(e))
                         continue
-                    self.logger.info('RECV: %s, %s, %s' % tuple(frame))
+                    self.logger.debug('RECV: %s, %s, %s' % tuple(frame))
                     self._frame_queue.put(frame)
             self.logger.debug('put Connection Lost in the queue')
             self._connected = False
@@ -142,7 +142,7 @@ class RTJPConnection(object):
         if not self._sock:
             raise Exception("Not Connected")
         self.frame_id += 1
-        self.logger.info('SEND: %s, %s, %s' % (self.frame_id, name, args))
+        self.logger.debug('SEND: %s, %s, %s' % (self.frame_id, name, args))
         buffer = core.serialize_frame(self.frame_id, name, args)
         e = eventlet.event.Event()
         eventlet.spawn(self._send_frame, self.frame_id, buffer, e)
